// $Id: repeat-button.h,v 1.2 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-

// RadioActive Copyright (C) 1999-2000 RDI Gerg <cactus@cactus.rulez.org>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 2
// (included in the RadioActive distribution in doc/GPL) as published by
// the Free Software Foundation.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
// $Id: repeat-button.h,v 1.2 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-

#ifndef RADIOACTIVE_repeat_button
#define RADIOACTIVE_repeat_button

#include <gtk--/button.h>

class RepeatButton: public Gtk::Button
{
public:
    RepeatButton (int time = 0);
    
    RepeatButton (const std::string &text = "",
		  int                time = 0);

    SigC::Signal0<void> hold;
private:
    unsigned int button_mask;
    int timeout_time;
    int button_press_handler (GdkEventButton *e);
    int button_release_handler (GdkEventButton *e);
    int timeout_handler ();
};

#endif
